# manowar_agent

[![Build Status](https://travis-ci.org/chalbersma/manowar_agent.svg?branch=master)](https://travis-ci.org/chalbersma/manowar_agent)

Agent for Manowar. Designed to be an agent that you can stick on a box and
get a moderately complete picture of what is on the device.

* [PyPi Prod](https://pypi.org/project/manowar-agent/)
* [PyPi Test](https://test.pypi.org/project/manowar-agent/)
